import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1
import Ubuntu.Content 0.1



/*!
    \brief MainView with a Label and Button elements.
*/

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "mainView"
    
    // Note! applicationName needs to match the "name" field of the click manifest
    applicationName: "com.ubuntu.developer.ken-vandine.hub-exporter"
    
    /* 
     This property enables the application to change orientation 
     when the device is rotated. The default is false.
    */
    //automaticOrientation: true
    
    width: units.gu(100)
    height: units.gu(75)
    
    Page {
        id: root
        title: i18n.tr("Hub Exporter")
        property var activeTransfer
        property bool pickMode: (root.activeTransfer.state === ContentTransfer.InProgress && root.activeTransfer.direction === ContentTransfer.Import)

        onPickModeChanged: {
            console.log("pickMode changed: " + root.pickMode);
        }

        function __exportItems(item)
        {
            var results = [];
            if (item)
                results.push(resultComponent.createObject(root, {"url": item}));
            else
            {
                for (var i = 0; i < images.count; i++)
                {
                    if (images.get(i).selected)
                        results.push(resultComponent.createObject(root, {"url": Qt.resolvedUrl(images.get(i).src)}));
                }
            }
            if (results.length > 0)
            {
                root.activeTransfer.items = results;
                root.activeTransfer.state = ContentTransfer.Charged;
            }
        }

        ListModel {
            id: images

            ListElement {
                src: "ubuntuone-music.png"
                selected: false
            }

            ListElement {
                src: "ubuntuone.png"
                selected: false
            }

            ListElement {
                src: "google-chrome.png"
                selected: false
            }
        }

        GridView {
            id: imagesView
            anchors.fill: parent
            model: images
            cellWidth: 128
            cellHeight: 128
            delegate: itemDelegate
        }

        Component {
            id: resultComponent
            ContentItem {}
        }

        Component {
            id: itemDelegate
            Item {
                id: curItem
                width: 128
                height: 128

                property string url: Qt.resolvedUrl(src)
                property bool selected: selected

                function toggle() {
                    selected = !selected;
                    for (var i = 0; i < images.count; i++)
                    {
                        if (images.get(i).src === src)
                        {
                            images.setProperty(i, "selected", selected);
                        }
                    }
                }

                UbuntuShape {
                    width: parent.width
                    height: width
                    image: Image {
                        id: image
                        source: url
                        height: parent.width
                        width: height
                        fillMode: Image.PreserveAspectFit
                        smooth: true
                    }

                    MouseArea {
                        anchors.fill: parent
                        enabled: root.pickMode
                        onClicked: {
                            toggle();
                        }
                    }

                    Image {
                        id: selectionTick
                        anchors.right: parent.right
                        anchors.top: parent.top
                        width: units.gu(5)
                        height: units.gu(5)
                        visible: curItem.selected && root.pickMode
                        source: "photo-preview-selected-overlay.png"
                    }

                    MouseArea {
                        anchors.fill: parent
                        enabled: !root.pickMode
                        onClicked: {
                            actPop.show();
                        }
                    }

                    ActionSelectionPopover {
                        id: actPop
                        delegate: ListItem.Standard {
                          text: action.text
                        }

                        contentWidth: childrenRect.width

                        actions: ActionList {
                          Action {
                              text: "Open with..."
                              onTriggered: {
                                  actPop.hide();
                                  print(text + ": " + url);
                                  var peer = picDest.createObject(root, {"appId": "com.ubuntu.developer.ken-vandine.hub-importer_hub-importer_0.2"});
                                  var transfer = ContentHub.exportContent(ContentType.Pictures, peer);
                                  if (transfer)
                                  {
                                      console.log ("Transfer state:" + transfer.state);
                                      root.activeTransfer = transfer;

                                      if (root.activeTransfer.state === ContentTransfer.InProgress)
                                          root.__exportItems(url);
                                  }
                              }
                          }
                          Action {
                              text: "Share"
                              onTriggered: {
                                  actPop.hide();
                                  print(text + ": " + url);
                                  var peer = picDest.createObject(root, {"appId": "com.ubuntu.developer.ken-vandine.hub-importer_hub-importer_0.2"});
                                  var transfer = ContentHub.shareContent(ContentType.Pictures, peer);
                                  if (transfer)
                                  {
                                      root.activeTransfer = transfer;
                                      console.log ("Transfer state:" + root.activeTransfer.state);

                                      if (root.activeTransfer.state === ContentTransfer.InProgress)
                                          root.__exportItems(url);
                                  }
                              }
                          }
                        }
                    }
                }
            }
        }

        Component {
            id: picDest
            ContentPeer {}
        }

        Connections {
            target: root.activeTransfer
            onStateChanged: {
                console.log("StateChanged: " + root.activeTransfer.state);
            }
        }


        Connections {
            target: ContentHub
            onExportRequested: {
                root.activeTransfer = transfer;
                console.log ("onExportRequested: " + root.activeTransfer.state);
            }
        }


        ListItem.Empty {
            id: pickerButtons
            anchors {
                left: parent.left
                right: parent.right
                bottom: parent.bottom
                margins: units.gu(2)
            }
            visible: root.pickMode
            Button {
                anchors {
                    left: parent.left
                    bottom: parent.bottom
                    margins: units.gu(2)
                }
                text: "Cancel"
                onClicked: root.activeTransfer.state = ContentTransfer.Aborted;
            }

            Button {
                anchors {
                    right: parent.right
                    bottom: parent.bottom
                    margins: units.gu(2)
                }
                text: "Select"
                onClicked: {
                    console.log("onClicked: charging");
                    root.__exportItems();
                }
            }
        }
    }
}

